@@ -8,10 +8,12 @@
 #include <alloca.h>
 #include <limits.h>
 #include <ctype.h>
+#include <termios.h>
 
 #include "kinit.h"
 #include "ipconfig.h"
 #include "run-init.h"
+#include "resume.h"
 
 const char *progname = "kinit";
 int mnt_procfs;
@@ -39,12 +41,14 @@ void dump_args(int argc, char *argv[])
 static int do_ipconfig(int argc, char *argv[])
 {
 	int i, a = 0;
-	char **args = alloca((argc + 1) * sizeof(char *));
+	char **args = alloca((argc + 3) * sizeof(char *));
 
 	if (!args)
 		return -1;
 
 	args[a++] = (char *)"IP-Config";
+	args[a++] = (char *)"-i";
+	args[a++] = (char *)"Linux kinit";
 
 	DEBUG(("Running ipconfig\n"));
 
@@ -317,5 +321,13 @@ bail:
 	if (mnt_sysfs)
 		umount2("/sys", 0);
 
-	exit(ret);
+	/*
+	 * If we get here, something bad probably happened, and the kernel
+	 * will most likely panic.  Drain console output so the user can
+	 * figure out what happened.
+	 */
+	tcdrain(2);
+	tcdrain(1);
+
+	return ret;
 }
