@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------- *
  *
- *   Copyright 2004 H. Peter Anvin - All Rights Reserved
+ *   Copyright 2004-2006 H. Peter Anvin - All Rights Reserved
  *
  *   Permission is hereby granted, free of charge, to any person
  *   obtaining a copy of this software and associated documentation
@@ -65,7 +65,8 @@ static int nuke_dir(const char *what)
 	struct dirent *d;
 	int err = 0;
 
-	if (!(dir = opendir(what))) {
+	dir = opendir(what);
+	if (!dir) {
 		/* EACCES means we can't read it.  Might be empty and removable;
 		   if not, the rmdir() in nuke() will trigger an error. */
 		return (errno == EACCES) ? 0 : errno;
@@ -111,7 +112,6 @@ static int nuke(const char *what)
 int main(int argc, char *argv[])
 {
 	int i;
-	int err = 0;
 
 	program = argv[0];
 
